@@ -8,6 +8,8 @@ class DependencyReflector(Reflector):
 	def reflect(self):
 		language_directory_mapping = collections.defaultdict(set)
 		for root, dirs, files in os.walk(self.repo_dir):
+			if 'node_modules' in root:
+				continue
 			if '.git' in dirs:
 				dirs.remove('.git')
 			if '.git' in files:
